@@ -9,12 +9,12 @@ ec2
 try:
     __version__ = __import__('pkg_resources') \
         .get_distribution('ec2').version
-except Exception:
+except Exception:  # pragma: no cover
     __version__ = 'unknown'
 
 __author__ = 'Matt Robenolt <matt@ydekproductions.com>'
 __license__ = 'BSD'
-__all__ = ('credentials', 'instances', 'security_groups')
+__all__ = ('credentials', 'instances', 'security_groups', 'vpcs')
 
 from .connection import credentials  # noqa
-from .types import instances, security_groups  # noqa
+from .types import instances, security_groups, vpcs  # noqa
