@@ -6,7 +6,7 @@ ec2.types
 :license: BSD, see LICENSE for more details.
 """
 
-from ec2.connection import get_connection
+from ec2.connection import get_connection, get_vpc_connection
 from ec2.base import objects_base
 
 
@@ -16,7 +16,10 @@ class instances(objects_base):
     @classmethod
     def _all(cls):
         "Grab all AWS instances"
-        return [i for r in get_connection().get_all_instances() for i in r.instances]
+        return [
+            i for r in get_connection().get_all_instances()
+            for i in r.instances
+        ]
 
 
 class security_groups(objects_base):
@@ -26,3 +29,12 @@ class security_groups(objects_base):
     def _all(cls):
         "Grab all AWS Security Groups"
         return get_connection().get_all_security_groups()
+
+
+class vpcs(objects_base):
+    "Singleton to stem off queries for virtual private clouds"
+
+    @classmethod
+    def _all(cls):
+        "Grab all AWS Virtual Private Clouds"
+        return get_vpc_connection().get_all_vpcs()
